@@ -3,14 +3,13 @@
 ## Download the list of images. Also use this opportunity to check
 ## the Internet connection and availability of the server.
 
-IMGLIST="imagelist-0.9.40"
+IMGLIST="imagelist-fremantle-01"
 
 mv $IMGLIST $IMGLIST.old
 wget -t 3 http://qole.org/$IMGLIST
 if [ $? != 0 ] ; then
   MSG1=`printf "\
 Cannot download the list of available images.\n\
-$? \
 Something is wrong with either your Internet connection\n\
 or the qole.org file server.\n\n\
 Check your Internet connection and the status\n\
@@ -146,14 +145,17 @@ cause your device to become unresponsive."`
      if [ "$?" = 0 ] ; then
 	 rm -rf $TARPATH/$BIGTAR1
          $EXTCMD1
+         ./msgnotify /usr/share/sounds/game-chess_checkmate.wav
          export MSG1=`printf "CONGRATULATIONS!\n\nAll has gone well!\n\nSuccess installing $PKGNAME1 package!"`
          gxmessage -center -alignbuttons right -buttons GTK_STOCK_OK:0 -geometry 640x250 -title "SUCCESS!" "$MSG1"
        else
+         ./msgnotify /usr/share/sounds/ui-information_note.wav
          export ERR1=`printf "ERROR! DECOMPRESSION FAILED!\nUnable to install $PKGNAME1\n$TARERR"`
          gxmessage -center -alignbuttons right -buttons GTK_STOCK_OK:0 -geometry 640x380 -title "DECOMPRESSION ERROR" "$ERR1"
          exit 99
       fi	
     else
+      ./msgnotify /usr/share/sounds/ui-information_note.wav
       export ERR1=`printf "$PKGNAME1 package appears damaged.\nPress OK to try downloading again.\nCancel keeps the damaged file."`
       gxmessage -center -alignbuttons right -buttons GTK_STOCK_OK:0,GTK_STOCK_CANCEL:1 -geometry 640x100 -title "DOWNLOAD ERROR" "$ERR1"
       if [ "$?" = 1 ] ; then
